@@ -98,7 +98,7 @@ ln_parseLegacyFieldDescr(ln_ctx ctx,
 
 	/* parse and process type (trailing whitespace must be trimmed) */
 	es_emptyStr(*str);
- 	size_t j = i;
+	size_t j = i;
 	/* scan for terminator */
 	while(j < lenBuf && buf[j] != ':' && buf[j] != '{' && buf[j] != '%')
 		++j;
@@ -319,7 +319,7 @@ parseLiteral(ln_ctx ctx, struct ln_pdag **pdag, es_str_t *rule,
 
 	/* we now add the string to the tree */
 	for(i = 0 ; cstr[i] != '\0' ; ++i) {
-		struct json_object *const prscnf = 
+		struct json_object *const prscnf =
 			newLiteralParserJSONConf(cstr[i]);
 		CHKN(prscnf);
 		CHKR(ln_pdagAddParser(ctx, pdag, prscnf));
@@ -472,7 +472,7 @@ addTagStrToBucket(ln_ctx ctx, es_str_t *tagname, struct json_object **tagBucket)
 {
 	int r = -1;
 	char *cstr;
-	struct json_object *tag; 
+	struct json_object *tag;
 
 	if(*tagBucket == NULL) {
 		CHKN(*tagBucket = json_object_new_array());
@@ -615,7 +615,7 @@ done:
 
 /**
  * Process a type definition and add it to the PDAG
- * disconnected components. 
+ * disconnected components.
  *
  * @param[in] ctx current context
  * @param[in] buf line buffer
@@ -666,7 +666,8 @@ done:	return r;
  * @returns 0 on success, something else otherwise
  */
 static int
-getFieldName(ln_ctx __attribute__((unused)) ctx, const char *buf, es_size_t lenBuf, es_size_t *offs, es_str_t **strTag)
+getFieldName(ln_ctx __attribute__((unused)) ctx, const char *buf, es_size_t lenBuf, es_size_t *offs,
+es_str_t **strTag)
 {
 	int r = -1;
 	es_size_t i;
@@ -739,13 +740,19 @@ getAnnotationOp(ln_ctx ctx, ln_annot *annot, const char *buf, es_size_t lenBuf,
 		goto done; /* nothing left to process (no error!) */
 	}
 
-	if(buf[i] == '+') {
+	switch(buf[i]) {
+	case '+':
 		opc = ln_annot_ADD;
-	} else if(buf[i] == '-') {
+		break;
+	case '#':
+		ln_dbgprintf(ctx, "inline comment in 'annotate' line: %s", buf);
+		*offs = lenBuf;
+		r = 0;
+		goto done;
+	case '-':
 		ln_dbgprintf(ctx, "annotate op '-' not yet implemented - failing");
-		goto fail;
-	} else {
-		ln_dbgprintf(ctx, "invalid annotate opcode '%c' - failing" , buf[i]);
+		/*FALLTHROUGH*/
+	default:ln_errprintf(ctx, 0, "invalid annotate operation '%c': %s", buf[i], buf+i);
 		goto fail;
 	}
 	i++;
@@ -896,14 +903,30 @@ done:
 }
 
 
+/**
+ * Read a character from our sample source.
+ */
+static int
+ln_sampReadChar(const ln_ctx ctx, FILE *const __restrict__ repo, const char **inpbuf)
+{
+	int c;
+	assert((repo != NULL && inpbuf == NULL) || (repo == NULL && inpbuf != NULL));
+	if(repo == NULL) {
+		c = (**inpbuf == '\0') ? EOF : *(*inpbuf)++;
+	} else {
+		c = fgetc(repo);
+	}
+	return c;
+}
+
 /* note: comments are only supported at beginning of line! */
 /* skip to end of line */
 void
-ln_sampSkipCommentLine(ln_ctx ctx, FILE * const __restrict__ repo)
+ln_sampSkipCommentLine(ln_ctx ctx, FILE * const __restrict__ repo, const char **inpbuf)
 {
 	int c;
 	do {
-		c = fgetc(repo);
+		c = ln_sampReadChar(ctx, repo, inpbuf);
 	} while(c != EOF && c != '\n');
 	++ctx->conf_ln_nbr;
 }
@@ -916,7 +939,7 @@ ln_sampSkipCommentLine(ln_ctx ctx, FILE * const __restrict__ repo)
  * @return 1 if this is a runaway rule, 0 if not
  */
 int
-ln_sampChkRunawayRule(ln_ctx ctx, FILE *const __restrict__ repo)
+ln_sampChkRunawayRule(ln_ctx ctx, FILE *const __restrict__ repo, const char **inpbuf)
 {
 	int r = 1;
 	fpos_t fpos;
@@ -934,12 +957,12 @@ ln_sampChkRunawayRule(ln_ctx ctx, FILE *const __restrict__ repo)
 		}
 		if(buf[0] == '\n') {
 			fsetpos(repo, &inner_fpos);
-			fread(buf, sizeof(char), 1, repo); /* skip '\n' */
+			if(fread(buf, sizeof(char), 1, repo)) {}; /* skip '\n' */
 			continue;
 		} else if(buf[0] == '#') {
 			fsetpos(repo, &inner_fpos);
 			const unsigned conf_ln_nbr_save = ctx->conf_ln_nbr;
-			ln_sampSkipCommentLine(ctx, repo);
+			ln_sampSkipCommentLine(ctx, repo, inpbuf);
 			ctx->conf_ln_nbr = conf_ln_nbr_save;
 			continue;
 		}
@@ -962,7 +985,6 @@ done:
 	return r;
 }
 
-
 /**
  * Read a rule (sample) from repository (sequentially).
  *
@@ -971,12 +993,16 @@ done:
  * pdag.
  *
  * @param[in] ctx current library context
- * @param[in] repo repository descriptor
+ * @param[in] repo repository descriptor if file input is desired
+ * @param[in/out] ptr to ptr of input buffer; this is used if a string is
+ *                provided instead of a file. If so, this pointer is advanced
+ *                as data is consumed.
  * @param[out] isEof must be set to 0 on entry and is switched to 1 if EOF occured.
  * @return standard error code
  */
 static int
-ln_sampRead(ln_ctx ctx, FILE *const __restrict__ repo, int *const __restrict__ isEof)
+ln_sampRead(ln_ctx ctx, FILE *const __restrict__ repo, const char **inpbuf,
+	int *const __restrict__ isEof)
 {
 	int r = 0;
 	char buf[64*1024]; /**< max size of rule - TODO: make configurable */
@@ -985,7 +1011,7 @@ ln_sampRead(ln_ctx ctx, FILE *const __restrict__ repo, int *const __restrict__ i
 	int inParser = 0;
 	int done = 0;
 	while(!done) {
-		int c = fgetc(repo);
+		const int c = ln_sampReadChar(ctx, repo, inpbuf);
 		if(c == EOF) {
 			*isEof = 1;
 			if(i == 0)
@@ -995,7 +1021,7 @@ ln_sampRead(ln_ctx ctx, FILE *const __restrict__ repo, int *const __restrict__ i
 		} else if(c == '\n') {
 			++ctx->conf_ln_nbr;
 			if(inParser) {
-				if(ln_sampChkRunawayRule(ctx, repo)) {
+				if(ln_sampChkRunawayRule(ctx, repo, inpbuf)) {
 					/* ignore previous rule */
 					inParser = 0;
 					i = 0;
@@ -1004,7 +1030,7 @@ ln_sampRead(ln_ctx ctx, FILE *const __restrict__ repo, int *const __restrict__ i
 			if(!inParser && i != 0)
 				done = 1;
 		} else if(c == '#' && i == 0) {
-			ln_sampSkipCommentLine(ctx, repo);
+			ln_sampSkipCommentLine(ctx, repo, inpbuf);
 			i = 0; /* back to beginning */
 		} else {
 			if(c == '%')
@@ -1079,7 +1105,12 @@ tryOpenRBFile(ln_ctx ctx, const char *const file)
 	}
 
 	char *fname = NULL;
-	asprintf(&fname, (rb_lib[strlen(rb_lib)-1] == '/') ? "%s%s" : "%s/%s", rb_lib, file);
+	int len;
+	len = asprintf(&fname, (rb_lib[strlen(rb_lib)-1] == '/') ? "%s%s" : "%s/%s", rb_lib, file);
+	if(len == -1) {
+		ln_errprintf(ctx, errno, "alloc error: cannot open rulebase '%s'", file);
+		goto done;
+	}
 	if((repo = fopen(fname, "r")) == NULL) {
 		const int eno2 = errno;
 		ln_errprintf(ctx, eno1, "cannot open rulebase '%s'", file);
@@ -1126,7 +1157,7 @@ ln_sampLoad(ln_ctx ctx, const char *file)
 	/* now we are in our native code */
 	++ctx->conf_ln_nbr; /* "version=2" is line 1! */
 	while(!isEof) {
-		CHKR(ln_sampRead(ctx, repo, &isEof));
+		CHKR(ln_sampRead(ctx, repo, NULL, &isEof));
 	}
 	fclose(repo);
 	r = 0;
@@ -1137,3 +1168,25 @@ done:
 	return r;
 }
 
+/* @return 0 if all is ok, 1 if an error occured */
+int
+ln_sampLoadFromString(ln_ctx ctx, const char *string)
+{
+	int r = 1;
+	int isEof = 0;
+
+	if(string == NULL)
+		goto done;
+
+	ln_dbgprintf(ctx, "loading v2 rulebase from string '%s'", string);
+	ctx->version = 2;
+	while(!isEof) {
+		CHKR(ln_sampRead(ctx, NULL, &string, &isEof));
+	}
+	r = 0;
+
+	if(ctx->include_level == 1)
+		ln_pdagOptimize(ctx);
+done:
+	return r;
+}
