@@ -40,7 +40,7 @@
 
 #ifdef FEATURE_REGEXP
 #include <pcre.h>
-#include <errno.h>			
+#include <errno.h>
 #endif
 
 
@@ -65,7 +65,7 @@ hParseInt(const unsigned char **buf, size_t *lenBuf)
 
 /* parsers for the primitive types
  *
- * All parsers receive 
+ * All parsers receive
  *
  * @param[in] str the to-be-parsed string
  * @param[in] strLen length of the to-be-parsed string
@@ -100,7 +100,7 @@ int ln_parse##ParserName(const char *const str, const size_t strLen, \
 parserdone: \
 	r = 0; \
 	goto done; /* suppress warnings */ \
-done: 
+done:
 
 #define ENDFailParser \
 	return r; \
@@ -200,7 +200,7 @@ PARSER(RFC5424Date)
 	int second;
 	__attribute__((unused)) int secfrac;	/* fractional seconds (must be 32 bit!) */
 	__attribute__((unused)) int secfracPrecision;
-	char OffsetHour;	/* UTC offset in hours */
+	int OffsetHour;		/* UTC offset in hours */
 	int OffsetMinute;	/* UTC offset in minutes */
 	size_t len;
 	size_t orglen;
@@ -211,7 +211,7 @@ PARSER(RFC5424Date)
 
 	year = hParseInt(&pszTS, &len);
 
-	/* We take the liberty to accept slightly malformed timestamps e.g. in 
+	/* We take the liberty to accept slightly malformed timestamps e.g. in
 	 * the format of 2003-9-1T1:0:0.  */
 	if(len == 0 || *pszTS++ != '-') goto done;
 	--len;
@@ -558,7 +558,7 @@ PARSER(Float)
 
 	i = *offs;
 
-	if (c[i] == '-') i++; 
+	if (c[i] == '-') i++;
 
 	for (; i < strLen; i++) {
 		if (c[i] == '.') {
@@ -566,11 +566,11 @@ PARSER(Float)
 			seen_point = 1;
 		} else if (! isdigit(c[i])) {
 			break;
-		} 
+		}
 	}
 	if (i == *offs)
 		goto done;
-		
+
 	/* success, persist */
 	*parsed = i - *offs;
 	r = 0; /* success */
@@ -713,7 +713,7 @@ PARSER(Word)
 	i = *offs;
 
 	/* search end of word */
-	while(i < strLen && c[i] != ' ') 
+	while(i < strLen && c[i] != ' ')
 		i++;
 
 	if(i == *offs)
@@ -759,7 +759,7 @@ PARSER(StringTo)
 		    j++;
 		    if(c[m] != toFind[j])
 			break;
-		    if (j == k) 
+		    if (j == k)
 			chkstr = 1;
 		}
 	    }
@@ -791,7 +791,7 @@ PARSER(Alpha)
 	i = *offs;
 
 	/* search end of word */
-	while(i < strLen && isalpha(c[i])) 
+	while(i < strLen && isalpha(c[i]))
 		i++;
 
 	if(i == *offs) {
@@ -829,7 +829,7 @@ PARSER(CharTo)
 	i = *offs;
 
 	/* search end of word */
-	while(i < strLen && c[i] != cTerm) 
+	while(i < strLen && c[i] != cTerm)
 		i++;
 
 	if(i == *offs || i == strLen || c[i] != cTerm)
@@ -866,7 +866,7 @@ PARSER(CharSeparated)
 	i = *offs;
 
 	/* search end of word */
-	while(i < strLen && c[i] != cTerm) 
+	while(i < strLen && c[i] != cTerm)
 		i++;
 
 	/* success, persist */
@@ -878,7 +878,7 @@ PARSER(CharSeparated)
 
 /**
  * Parse yet-to-be-matched portion of string by re-applying
- * top-level rules again. 
+ * top-level rules again.
  */
 #define DEFAULT_REMAINING_FIELD_NAME "tail"
 
@@ -945,7 +945,8 @@ done:
 		if (name == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for recursive/descent field name");
 		else if (pData == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for parser-data for field: %s", name);
 		else if (args == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for argument-parsing for field: %s", name);
-		else if (pData->ctx == NULL) ln_dbgprintf(ctx, "recursive/descent normalizer context creation doneed for field: %s", name);
+		else if (pData->ctx == NULL) ln_dbgprintf(ctx, "recursive/descent normalizer context creation "
+		"doneed for field: %s", name);
 		else if (pData->remaining_field == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for remaining-field name for "
 															  "recursive/descent field: %s", name);
 
@@ -977,8 +978,8 @@ static ln_ctx child_recursive_parse_ctx_constructor(ln_ctx parent_ctx, pcons_arg
 done:
 	if (r != 0) {
 		if (rb == NULL) ln_dbgprintf(parent_ctx, "file-name for descent rulebase not provided for field: %s", field_name);
-		else if (ctx == NULL) ln_dbgprintf(parent_ctx, "couldn't allocate memory to create descent-field normalizer context "
-										   "for field: %s", field_name);
+		else if (ctx == NULL) ln_dbgprintf(parent_ctx, "couldn't allocate memory to create descent-field "
+		"normalizer context for field: %s", field_name);
 		else ln_dbgprintf(parent_ctx, "couldn't load samples into descent context for field: %s", field_name);
 		if (ctx != NULL) ln_exitCtx(ctx);
 		ctx = NULL;
@@ -1217,7 +1218,8 @@ done:
 		else if (args == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for argument-parsing for field: %s", name);
 		else if (pData == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for parser-data for field: %s", name);
 		else if (tok == NULL) ln_dbgprintf(ctx, "token-separator not provided for field: %s", name);
-		else if (pData->tok_str == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for token-separator for field: %s", name);
+		else if (pData->tok_str == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for token-separator "
+		"for field: %s", name);
 		else if (field_descr == NULL) ln_dbgprintf(ctx, "field-type not provided for field: %s", name);
 		else if (field == NULL) ln_dbgprintf(ctx, "couldn't resolve single-token field-type for tokenized field: %s", name);
 		else if (pData->ctx == NULL) ln_dbgprintf(ctx, "couldn't initialize normalizer-context for field: %s", name);
@@ -1286,7 +1288,8 @@ done:
 	return r;
 }
 
-static const char* regex_parser_configure_consume_and_return_group(pcons_args_t* args, struct regex_parser_data_s *pData) {
+static const char* regex_parser_configure_consume_and_return_group(pcons_args_t* args,
+struct regex_parser_data_s *pData) {
 	const char* consume_group_parse_error = "couldn't parse consume-group number";
 	const char* return_group_parse_error = "couldn't parse return-group number";
 
@@ -1350,7 +1353,8 @@ done:
 		else if (unescaped_exp == NULL) ln_dbgprintf(ctx, "regular-expression missing for field: '%s'", name);
 		else if (exp == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for regex-string for field: '%s'", name);
 		else if (grp_parse_err != NULL)  ln_dbgprintf(ctx, "%s for: '%s'", grp_parse_err, name);
-		else if (pData->re == NULL)	ln_dbgprintf(ctx, "couldn't compile regex(encountered error '%s' at char '%d' in pattern) "
+		else if (pData->re == NULL)
+			ln_dbgprintf(ctx, "couldn't compile regex(encountered error '%s' at char '%d' in pattern) "
 												 "for regex-matched field: '%s'", error, erroffset, name);
 		regex_parser_data_destructor((void**)&pData);
 	}
@@ -1373,7 +1377,7 @@ void regex_parser_data_destructor(void** dataPtr) {
 
 /**
  * Parse yet-to-be-matched portion of string by re-applying
- * top-level rules again. 
+ * top-level rules again.
  */
 typedef enum interpret_type {
 	/* If you change this, be sure to update json_type_to_name() too */
@@ -1530,7 +1534,7 @@ void interpret_parser_data_destructor(void** dataPtr) {
 struct suffixed_parser_data_s {
 	int nsuffix;
 	int *suffix_offsets;
-    int *suffix_lengths;
+	int *suffix_lengths;
 	char* suffixes_str;
 	ln_ctx ctx;
 	char* value_field_name;
@@ -1544,8 +1548,8 @@ PARSER(Suffixed) {
 	json_object *unparsed = NULL;
 	json_object *parsed_raw = NULL;
 	json_object *parsed_value = NULL;
-    json_object *result = NULL;
-    json_object *suffix = NULL;
+	json_object *result = NULL;
+	json_object *suffix = NULL;
 
 	struct suffixed_parser_data_s *pData = (struct suffixed_parser_data_s*) node->parser_data;
 
@@ -1563,23 +1567,23 @@ PARSER(Suffixed) {
 		} else {
 			json_object_object_get_ex(parsed_raw, DEFAULT_MATCHED_FIELD_NAME, &parsed_value);
 			json_object_object_get_ex(parsed_raw, DEFAULT_REMAINING_FIELD_NAME, &unparsed);
-            const char* unparsed_frag = json_object_get_string(unparsed);
+		const char* unparsed_frag = json_object_get_string(unparsed);
 			for(i = 0; i < pData->nsuffix; i++) {
-                const char* possible_suffix = pData->suffixes_str + pData->suffix_offsets[i];
+		const char* possible_suffix = pData->suffixes_str + pData->suffix_offsets[i];
 				int len = pData->suffix_lengths[i];
 				if (strncmp(possible_suffix, unparsed_frag, len) == 0) {
-                    CHKN(result = json_object_new_object());
-                    CHKN(suffix = json_object_new_string(possible_suffix));
+				CHKN(result = json_object_new_object());
+				CHKN(suffix = json_object_new_string(possible_suffix));
 					json_object_get(parsed_value);
-                    json_object_object_add(result, pData->value_field_name, parsed_value);
-                    json_object_object_add(result, pData->suffix_field_name, suffix);
+				json_object_object_add(result, pData->value_field_name, parsed_value);
+				json_object_object_add(result, pData->suffix_field_name, suffix);
 					*parsed = strLen - *offs - json_object_get_string_len(unparsed) + len;
-                    break;
-                }
+				break;
+				}
+			}
+			if (result != NULL) {
+				*value = result;
 			}
-            if (result != NULL) {
-                *value = result;
-            }
 		}
 	}
 FAILParser
@@ -1644,7 +1648,7 @@ static struct suffixed_parser_data_s* _suffixed_parser_data_constructor(ln_field
 	while ((tok = strtok_r(tok_input, tokenizer, &tok_saveptr)) != NULL) {
 		tok_input = NULL;
 		pData->suffix_offsets[i] = tok - pData->suffixes_str;
-        pData->suffix_lengths[i++] = strlen(tok);
+	pData->suffix_lengths[i++] = strlen(tok);
 	}
 
 	CHKN(field_type = pcons_arg(args, 2, NULL));
@@ -1655,11 +1659,14 @@ done:
 	if (r != 0) {
 		if (name == NULL) ln_dbgprintf(ctx, "couldn't allocate memory suffixed-field name");
 		else if (pData == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for parser-data for field: %s", name);
-		else if (pData->value_field_name == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for value-field's name for field: %s", name);
-		else if (pData->suffix_field_name == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for suffix-field's name for field: %s", name);
+		else if (pData->value_field_name == NULL)
+			ln_dbgprintf(ctx, "couldn't allocate memory for value-field's name for field: %s", name);
+		else if (pData->suffix_field_name == NULL)
+			ln_dbgprintf(ctx, "couldn't allocate memory for suffix-field's name for field: %s", name);
 		else if (args == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for argument-parsing for field: %s", name);
 		else if (escaped_tokenizer == NULL) ln_dbgprintf(ctx, "suffix token-string missing for field: '%s'", name);
-		else if (tokenizer == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for unescaping token-string for field: '%s'", name);
+		else if (tokenizer == NULL)
+			ln_dbgprintf(ctx, "couldn't allocate memory for unescaping token-string for field: '%s'", name);
 		else if (uncopied_suffixes_str == NULL)  ln_dbgprintf(ctx, "suffix-list missing for field: '%s'", name);
 		else if (suffixes_str == NULL)  ln_dbgprintf(ctx, "couldn't allocate memory for suffix-list for field: '%s'", name);
 		else if (pData->nsuffix == 0)  ln_dbgprintf(ctx, "could't read suffix-value(s) for field: '%s'", name);
@@ -1670,7 +1677,8 @@ done:
 		else if (pData->suffixes_str == NULL)
 			ln_dbgprintf(ctx, "couldn't allocate memory for suffix-list for field: '%s'", name);
 		else if (field_type == NULL)  ln_dbgprintf(ctx, "field-type declaration missing for field: '%s'", name);
-		else if (pData->ctx == NULL)  ln_dbgprintf(ctx, "couldn't allocate memory for normalizer-context for field: '%s'", name);
+		else if (pData->ctx == NULL)
+			ln_dbgprintf(ctx, "couldn't allocate memory for normalizer-context for field: '%s'", name);
 		suffixed_parser_data_destructor((void**)&pData);
 	}
 	free_pcons_args(&args);
@@ -1707,7 +1715,8 @@ done:
 		else if (args == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for argument-parsing for field: %s", name);
 		else if (value_field_name == NULL) ln_dbgprintf(ctx, "key-name for value not provided for field: %s", name);
 		else if (suffix_field_name == NULL) ln_dbgprintf(ctx, "key-name for suffix not provided for field: %s", name);
-		else if (unnamed_suffix_args == NULL) ln_dbgprintf(ctx, "couldn't allocate memory for unnamed-suffix-field args for field: %s", name);
+		else if (unnamed_suffix_args == NULL)
+			ln_dbgprintf(ctx, "couldn't allocate memory for unnamed-suffix-field args for field: %s", name);
 		else if (pData == NULL) ln_dbgprintf(ctx, "couldn't create parser-data for field: %s", name);
 		suffixed_parser_data_destructor((void**)&pData);
 	}
@@ -1767,7 +1776,7 @@ PARSER(OpQuotedString)
 	i = *offs;
 
 	if(c[i] != '"') {
-		while(i < strLen && c[i] != ' ') 
+		while(i < strLen && c[i] != ' ')
 			i++;
 
 		if(i == *offs)
@@ -1781,7 +1790,7 @@ PARSER(OpQuotedString)
 	    ++i;
 
 	    /* search end of string */
-	    while(i < strLen && c[i] != '"') 
+	    while(i < strLen && c[i] != '"')
 		    i++;
 
 	    if(i == strLen || c[i] != '"')
@@ -1824,7 +1833,7 @@ PARSER(QuotedString)
 	++i;
 
 	/* search end of string */
-	while(i < strLen && c[i] != '"') 
+	while(i < strLen && c[i] != '"')
 		i++;
 
 	if(i == strLen || c[i] != '"')
@@ -1899,7 +1908,7 @@ done:
  *   outside:192.168.52.102/50349
  *   inside:192.168.1.15/56543 (192.168.1.112/54543)
  *   outside:192.168.1.13/50179 (192.168.1.13/50179)(LOCAL\some.user)
- *   outside:192.168.1.25/41850(LOCAL\RG-867G8-DEL88D879BBFFC8) 
+ *   outside:192.168.1.25/41850(LOCAL\RG-867G8-DEL88D879BBFFC8)
  *   inside:192.168.1.25/53 (192.168.1.25/53) (some.user)
  *   192.168.1.15/0(LOCAL\RG-867G8-DEL88D879BBFFC8)
  * From this, we conclude the format is:
@@ -2239,7 +2248,7 @@ done:
 }
 
 
-/* skip past the IPv6 address block, parse pointer is set to 
+/* skip past the IPv6 address block, parse pointer is set to
  * first char after the block. Returns an error if already at end
  * of string.
  * @param[in] str parse buffer
@@ -2358,11 +2367,11 @@ isValidIPTablesNameChar(const char c)
 	return ('A' <= c && c <= 'Z') ? 1 : 0;
 }
 
-/* helper to iptables parser, parses out a a single name=value pair 
+/* helper to iptables parser, parses out a a single name=value pair
  */
 static int
 parseIPTablesNameValue(const char *const __restrict__ str,
-	const size_t strLen, 
+	const size_t strLen,
 	size_t *const __restrict__ offs,
 	struct json_object *const __restrict__ valroot)
 {
@@ -2535,7 +2544,7 @@ isValidNameChar(const char c)
 		|| c == '-'
 		) ? 1 : 0;
 }
-/* helper to NameValue parser, parses out a a single name=value pair 
+/* helper to NameValue parser, parses out a a single name=value pair
  *
  * name must be alphanumeric characters, value must be non-whitespace
  * characters, if quoted than with symmetric quotes. Supported formats
@@ -2547,7 +2556,7 @@ isValidNameChar(const char c)
  */
 static int
 parseNameValue(const char *const __restrict__ str,
-	const size_t strLen, 
+	const size_t strLen,
 	size_t *const __restrict__ offs,
 	struct json_object *const __restrict__ valroot)
 {
