@@ -27,7 +27,28 @@ execute() {
 	echo "====================="
 	set -x
     fi
-    echo "$1" | $cmd $ln_opts -r tmp.rulebase -e json > test.out 
+    if [ "$1" == "file" ]; then
+        $cmd $ln_opts -r tmp.rulebase -e json > test.out < $2
+    else
+        echo "$1" | $cmd $ln_opts -r tmp.rulebase -e json > test.out
+    fi
+    echo "Out:"
+    cat test.out
+    if [ "x$debug" == "xon" ]; then
+	set +x
+    fi
+}
+
+execute_with_string() {
+    # $1 must be rulebase string
+    # $2 must be sample string
+    if [ "x$debug" == "xon" ]; then
+	echo "======rulebase======="
+	cat tmp.rulebase
+	echo "====================="
+	set -x
+    fi
+    echo "$2" | $cmd $ln_opts -R "$1" -e json > test.out
     echo "Out:"
     cat test.out
     if [ "x$debug" == "xon" ]; then
