@@ -1,6 +1,8 @@
 # added 2014-11-18 by singh.janmejay
 # This file is part of the liblognorm project, released under ASL 2.0
-source ./exec.sh $0 "tokenized field with invalid rule definition"
+. $srcdir/exec.sh
+
+test_def $0 "tokenized field with invalid rule definition"
 
 add_rule 'rule=:%arr:tokenized%'
 execute '123 abc 456 def'
@@ -36,3 +38,7 @@ add_rule 'rule=:%arr:tokenized::::%%%%'
 execute '123 abc 456 def'
 assert_output_contains '"unparsed-data": "123 abc 456 def"'
 assert_output_contains '"originalmsg": "123 abc 456 def"'
+
+
+cleanup_tmp_files
+
